#!/usr/bin/perl

use Fcntl;

$prefix = "/var/.sniffer";
$logdir = "$prefix/spool";
$lockFile = "$prefix/lock/web-block.lck";
%prevIP = ();

# Clean up from kill -15
sub killFifteen () {
    unlink ( $lockFile );
    print "web-block.pl: Terminated\n";
    exit ( 0 );
}

if ( fork () == 0 ) {
    # child; do nothing
} else {
    # parent; die to become a daemon
    exit ( 0 );
}

# Attempt to create my lock file
sysopen ( LCK, $lockFile, O_CREAT|O_EXCL|O_RDWR ) or die "unable to create $lockFile: $!";
print LCK "$$\n";
close ( LCK );

# Register my kill -15 handler
$SIG{TERM} = \&killFifteen;

open ( SRC, "$prefix/pipes/block-pipe" );

while ( <SRC> ) {
    chomp;
    # Filter out the multiple hits we get (one for each packet in the stream)
    if ( $prevIP{$_} ne "yes" ) {

	# Write an input block chain first, to stop as much of the
	# page from loading as possible.  No need to write the input
	# block to /etc/sysconfig/ipchains, because the output chain
	# will prevent contact in the future.
	system ( "/sbin/ipchains -A input -s $_/32 -d 0.0.0.0/0.0.0.0 -i eth0 -j REJECT" );
	system ( "/sbin/ipchains -A output -s 0.0.0.0/0.0.0.0 -d $_/32 -i eth0 -j REJECT" );

	# Block access to the site in the future.
	open ( CHAIN, ">>/etc/sysconfig/ipchains" );
	print CHAIN "-A output -s 0.0.0.0/0.0.0.0 -d $_/32 -i eth0 -j REJECT\n";
	close ( CHAIN );

	# This allows us to only block the IP once.  The scanner
	# frequently generates multiple hits on a site with bad words.
	$prevIP{$_} = "yes";

    }
}
