#!/usr/bin/perl -w

use strict;
use Fcntl;

# Run tcpdump, and watch for nasty stuff.  Eventually block the site
# with either iptables or ipchains.

package main;
our $prefix = "/var/.sniffer";
our $lockFile = "$prefix/lock/web-log.lck";

# Clean up from kill -15
sub killFifteen () {
    unlink ( $lockFile );
    print "web-log.pl: Terminated\n";
    close ( TOLOG );
    exit ( 0 );
}

# Return a string with the current date in pretty format
sub prettyDate () {
    my $retDate;
    my @pt = localtime ( time );
    $retDate = sprintf ( "%02d/%02d/%04d %02d:%02d:%02d", $pt[4]+1, $pt[3], $pt[5]+1900, $pt[2], $pt[1], $pt[0] );
    return "$retDate";
}

# Become a daemon
if ( fork () == 0 ) {
    # child; do nothing
} else {
    # parent; die to become a daemon
    exit ( 0 );
}

# Attempt to create my lock file
sysopen ( LCK, $lockFile, O_CREAT|O_EXCL|O_RDWR ) or die "unable to create $lockFile: $!";
print LCK "$$\n";
close ( LCK );

# Register my kill -15 handler
$SIG{TERM} = \&killFifteen;

open ( TOLOG, "<$prefix/pipes/log-pipe" );

while ( <TOLOG> ) {
    open ( LOG, ">>$prefix/block.log" );
    my $pd = prettyDate ();
    print LOG "$pd $_";
    close ( LOG );
}

