#!/usr/bin/perl

use Fcntl;

$prefix = "/var/.sniffer";
$lockFile = "$prefix/lock/web-scan.lck";
$logdir = "$prefix/spool";
$webIP = "";
@matchList = `cat $prefix/web-scan.conf`;

# Clean up from kill -15
sub killFifteen () {
    unlink ( $lockFile );
    print "web-scan.pl: Terminated\n";
    exit ( 0 );
}

# Become a daemon
if ( fork () == 0 ) {
    # child; do nothing
} else {
    # parent; die to become a daemon
    exit ( 0 );
}

# Attempt to create my lock file
sysopen ( LCK, $lockFile, O_CREAT|O_EXCL|O_RDWR ) or die "unable to create $lockFile: $!";
print LCK "$$\n";
close ( LCK );

# Register my kill -15 handler
$SIG{TERM} = \&killFifteen;

open ( SRC, "$prefix/pipes/scan-pipe" );
open ( BLOCK, ">$prefix/pipes/block-pipe" );
open ( LOG, ">$prefix/pipes/log-pipe" );
$| = 1; # Autoflush after each write

while ( <SRC> ) {
#    print "$_";
    chomp;
    
    # Scan only the web traffic back to us, for now.  Ignore everything else.
    if ( /(^\d+\.\d+\.\d+\.\d+)\.http\-/ ) {
	# Filter
	$webIP = $1;
	$hit = scanFile ( $_ );
    } else {
	# Don't Filter
    }

    if ( $hit ) {
	# Save the file
    } else {
	unlink ( "$logdir/$_" );
    }
}

# Returns 1 if it found a match, else 0
sub scanFile () {
    $filename = shift;
    $hit = 0;
    $return = 0;

#    print "$filename\n";

    $bigBuff = `cat $logdir/$filename`;

    foreach $match (@matchList) {
	chomp ( $match );
	if ( index ( $bigBuff, $match ) != -1 ) {

	    print LOG "web-scan: Found \"$match\" in $filename\n";
	    
	    $return = 1;
	
	    print BLOCK "$webIP\n";
	    last;
	}
    }

    return $return;

}
